installing
==========

You can install PySMSBoxNet using pip:

.. code-block:: shell

   pip install pysmsboxnet

If you want to test a beta version, you can add the ``pre`` command line argument:

.. code-block:: shell

   pip install --pre pysmsboxnet

Updating
========

Updating is also possible using pip:

.. code-block:: shell

   pip install --upgrade pysmsboxnet
